#!/usr/bin/env bash

export DISPLAY=:255
export XAUTHORITY=/home/autologon/.Xauthority

function getBus()                                                                                                                                                                                                                     
{                                                                                                                                                                                                                                     
    node=$(xinput list-props $1 | grep 'Device Node' | cut -d'"' -f 2)                                                                                                                                                                
    bus=$(udevadm info --query=property --name=$node | grep DEVPATH= | sed -e 's/^DEVPATH=.*\([0-9]\+\-[0-9]\+\(\.[0-9]\+\)*\:[0-9]\+\.[0-9]\+\).*/\1/')                                                                              
    echo "$bus"                                                                                                                                                                                 
}

function choiceDevice() 
{
    IFS=$'\n'
    local i=1
    local j=1
    for var in $1
    do
        IFS='|' read -r name id <<< $var
        array[ $i ]=$j
        bus=$(getBus "$id")
        array[ ($i + 1) ]="$name ($bus)"
        devices[$j]="$name"
        (( j++ ))
        (( i=($i+2) ))
    done

    local cmd=(dialog --title 'Выберите устройство' --menu 'Выберите устройство для калибровки' 22 76 16)
    local choices=$("${cmd[@]}" "${array[@]}" 2>&1 >/dev/tty)

    echo "${devices[$choices]}"
}

tmp_conffile=/tmp/xinput_calibrator.conf

rm -f $tmp_conffile

out_xrandr=$(xrandr)
primary_resolution=$(sed -n 's/.*primary \([0-9x]*\)+.*/\1/p' <<< $out_xrandr)

if [ -z $primary_resolution ]; then
    geometry=""
else
    geometry="--geometry $primary_resolution"
    echo "Разрешение основного экрана: $primary_resolution"
fi

device=$(xinput_calibrator --list | sed -n 's/.*Device\s\"\(.*\)\"[ ]\+id=\([0-9]\+\)/\1|\2/p')
device_count=$(echo -n "$device" | grep -c '^')

case $device_count in
    0 )
        echo "Нет устройств для калибровки"
        exit 1
        ;;
    1 ) ;;
    * )
        device=$(choiceDevice "$device")
        [[ -z $device ]] && exit 1
        ;;
esac

rotate=$(xrandr --current --verbose | grep primary | egrep -o -m 1 '(normal|left|inverted|right)' | head -1)
echo "Поворот экрана: $rotate"

cd /linuxcash/cash/bin/

# сбросить старые настройки
# установить матрицу трансформации по умолчанию для заданного поворота экрана
xinput set-prop "$device" 'Coordinate Transformation Matrix' $(python3 _gmutils/tfmatrix.py "$rotate" "$out_xrandr")

chvt $(cat /tmp/cash_tty)
out=$(xinput_calibrator -v --geometry "$primary_resolution" --device "$device")
calibration_option=$(echo "$out" | grep "\"Calibration\"")

# вычисляем матрицу трансформации
tf_matrix=$(python3 _gmutils/tfmatrix.py "$rotate" "$out_xrandr" "$out")

echo "Матрица трансформации: $tf_matrix"

# применить новые настройки
xinput set-prop "$device" 'Coordinate Transformation Matrix' $tf_matrix

echo "Section \"InputClass\"" > $tmp_conffile
echo "        Identifier \"calibration\"" >> $tmp_conffile
echo "        MatchProduct \"$device\"" >> $tmp_conffile
if [ -n "$calibration_option" ]; then
    echo "$calibration_option" >> $tmp_conffile
fi
echo "        Option \"TransformationMatrix\" \"$tf_matrix\"" >> $tmp_conffile
echo "EndSection" >> $tmp_conffile

cp $tmp_conffile /usr/share/X11/xorg.conf.d/99-calibration.conf
